==> qmpdclient-1.0.6.2.tar.gz: qmpdclient-1.0.6.2/src/stringlistmodel.cpp <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "config.h"
#include "stringlistmodel.h"

StringListModel::StringListModel(QObject *parent) : QAbstractListModel(parent) {
	setObjectName("stringlistmodel");
}

QVariant StringListModel::data(const QModelIndex &index, int role) const {
	if (!index.isValid() || index.row() < 0 || index.row() > lst.size())
		return QVariant();

	if (role == Qt::DisplayRole) {
		if (index.row() == 0)
			return QObject::tr("All", "This is the first item in the artist and album views, meaning \"All artists\" or \"All albums\"");
		if (lst.at(index.row()-1).isEmpty())
			return QObject::tr("Not tagged", "This is the second item in the artist and album views, meaning \"Files belonging to no artist or no albums\"");
		return lst.at(index.row()-1);
	}
	else if (role == Qt::FontRole && (index.row() == 0 || lst.at(index.row()-1).isEmpty())) {
		QFont font = Config::instance()->font();
		font.setBold(true);
		return font;
	}
	return QVariant();
}

Qt::ItemFlags StringListModel::flags(const QModelIndex &index) const {
	return QAbstractItemModel::flags(index) | Qt::ItemIsDragEnabled;
}

QString StringListModel::string(const QModelIndex &index) {
	if (index.isValid()) {
		if (index.row() == 0)
			return QString::null;
		if (lst.at(index.row()-1).isEmpty())
			return QString("");
		return data(index, Qt::DisplayRole).toString();
	}
	return QString::null;
}

QStringList StringListModel::stringList(QModelIndexList indexes) {
	QStringList ret;
	foreach (QModelIndex index, indexes) {
		ret << string(index);
	}
	return ret;
}

QStringList StringListModel::stringList() const {
	return lst;
}

void StringListModel::setStringList(const QStringList &strings) {
	lst = strings;
	reset();
}

int StringListModel::rowCount(const QModelIndex &) const {
	return lst.size()+1;
}

==> qmpdclient-1.0.7.tar.gz: qmpdclient-1.0.7/src/stringlistmodel.cpp <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "config.h"
#include "stringlistmodel.h"
#include "stringlistview.h"
#include <QMimeData>

StringListModel::StringListModel(QObject *parent) : QAbstractListModel(parent) {
	setObjectName("stringlistmodel");
	m_view = qobject_cast<StringListView*>(parent);
}

QVariant StringListModel::data(const QModelIndex &index, int role) const {
	if (!index.isValid() || index.row() < 0 || index.row() > m_list.size())
		return QVariant();

	if (role == Qt::DisplayRole) {
		if (index.row() == 0)
			return QObject::tr("All", "This is the first item in the artist and album views, meaning \"All artists\" or \"All albums\"");
		if (m_list.at(index.row()-1).isEmpty())
			return QObject::tr("Not tagged", "This is the second item in the artist and album views, meaning \"Files belonging to no artist or no albums\"");
		return m_list.at(index.row()-1);
	} else if (role == Qt::FontRole && (index.row() == 0 || m_list.at(index.row()-1).isEmpty())) {
		QFont font = Config::instance()->font();
		font.setBold(true);
		return font;
	}
	return QVariant();
}

Qt::ItemFlags StringListModel::flags(const QModelIndex &index) const {
	return QAbstractItemModel::flags(index) | Qt::ItemIsDragEnabled;
}

QString StringListModel::string(const QModelIndex &index) const {
	if (index.isValid()) {
		if (index.row() == 0)
			return QString::null;
		if (m_list.at(index.row()-1).isEmpty())
			return QString("");
		return data(index, Qt::DisplayRole).toString();
	}
	return QString::null;
}

QStringList StringListModel::stringList(const QModelIndexList &indexes) const {
	QStringList ret;
	foreach (QModelIndex index, indexes) {
		ret << string(index);
	}
	return ret;
}

QStringList StringListModel::stringList() const {
	return m_list;
}

void StringListModel::setStringList(const QStringList &strings) {
	m_list = strings;
	reset();
}

int StringListModel::rowCount(const QModelIndex &) const {
	return m_list.size()+1;
}

QStringList StringListModel::mimeTypes() const {
	return QStringList() << "qmpdclient/song";
}

QMimeData *StringListModel::mimeData(const QModelIndexList &indexes) const {
	QByteArray encodedData;
	QDataStream stream(&encodedData, QIODevice::WriteOnly);
	foreach (MPDSong song, m_view->getSelectedSongs()) {
		stream << song;
	}
	QMimeData *mimeData = new QMimeData();
	mimeData->setData("qmpdclient/song", encodedData);
	return mimeData;
}
